==> adme16cod.db_2.0.1.tar.gz: adme16cod.db/man/adme16cod_dbconn.Rd <==
\name{adme16cod_dbconn}

\alias{adme16cod_dbconn}
\alias{adme16cod_dbfile}
\alias{adme16cod_dbschema}
\alias{adme16cod_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  adme16cod_dbconn()
  adme16cod_dbfile()
  adme16cod_dbschema(file="", show.indices=FALSE)
  adme16cod_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{adme16cod_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{adme16cod_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{adme16cod_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{adme16cod_dbschema} prints the schema definition of the
  package annotation DB.

  \code{adme16cod_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{adme16cod_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{adme16cod_dbfile}: a character string with the path to the
  package annotation DB.

  \code{adme16cod_dbschema}: none (invisible \code{NULL}).

  \code{adme16cod_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(adme16cod_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by adme16cod_dbconn() was created with:
  dbConnect(SQLite(), dbname=adme16cod_dbfile(), cache_size=64000, synchronous=0)

  adme16cod_dbschema()

  adme16cod_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> adme16cod.db_2.14.0.tar.gz: adme16cod.db/man/adme16cod_dbconn.Rd <==

\name{adme16cod_dbconn}

\alias{adme16cod_dbconn}
\alias{adme16cod_dbfile}
\alias{adme16cod_dbschema}
\alias{adme16cod_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  adme16cod_dbconn()
  adme16cod_dbfile()
  adme16cod_dbschema(file="", show.indices=FALSE)
  adme16cod_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{adme16cod_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{adme16cod_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{adme16cod_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{adme16cod_dbschema} prints the schema definition of the
  package annotation DB.

  \code{adme16cod_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{adme16cod_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{adme16cod_dbfile}: a character string with the path to the
  package annotation DB.

  \code{adme16cod_dbschema}: none (invisible \code{NULL}).

  \code{adme16cod_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(adme16cod_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by adme16cod_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=adme16cod_dbfile(), cache_size=64000,
  synchronous=0)

  adme16cod_dbschema()

  adme16cod_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
